<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<gui name="%{APPNAME}" version="0.1">
  <MenuBar>
    <Menu name="file" >
      <Action name="showcurrentmonth" />
<!--      <Separator/>-->
    </Menu>
  </MenuBar>
  <ToolBar name="mainToolBar" >
    <text>Main Toolbar</text>
      <Action name="showcurrentmonth" />
<!--      <Separator/>-->
      <ActionList name="dynamicActionlist" />
  </ToolBar>
</gui>
