<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="%{APPNAMELC}" version="1">
<MenuBar>
  <Menu name="move"><text>&amp;Move</text>
    <Action name="switch_action" />
  </Menu>
</MenuBar>
</kpartgui>
